@@ -3,7 +3,7 @@ from quickcsv.file import *
 from collections import OrderedDict
 import os
 
-def divide_by_tag(meta_csv_file,raw_text_folder,output_folder,list_category, start_year=2010,end_year=2021, tag_field="tag",keyword_field="keyword",time_field="time",id_field="Id",prefix_filename=""):
+def divide_by_tag(meta_csv_file,raw_text_folder,output_folder,list_category, start_year=2010,end_year=2021, tag_field="tag",keyword_field="keyword",year_field='year',time_field="time",id_field="Id",prefix_filename=""):
 
     if not os.path.exists(output_folder):
         os.mkdir(output_folder)
@@ -23,11 +23,15 @@ def divide_by_tag(meta_csv_file,raw_text_folder,output_folder,list_category, sta
         if keyword_field in item.keys():
             keyword = item[keyword_field]
         Id = item[id_field]
+
         time = item[time_field]
         year = ""
         if '-' in time:
             year = time.split("-")[0]
 
+        if year_field != "":
+            year=item[year_field]
+
         model = {
             "Id": Id,
             "Year": year,
