@@ -6,15 +6,15 @@ from quickcsv.file import *
 import jieba
 import jieba.posseg as pseg
 
-def LDA(field,list_doc,weights_path,list_keywods_path,stopwords_path,num_topics=6):
+def LDA(field,list_doc,weights_path,list_keywods_path,stopwords_path,num_topics=6,num_words=50,num_pass=5):
 
     # ============ begin configure ====================
     NUM_TOPICS = num_topics
-    NUM_WORDS = 50
+    NUM_WORDS = num_words
     FIG_V_NUM = 2
     FIG_H_NUM = 3
     WC_MAX_WORDS = 20
-    NUM_PASS = 5
+    NUM_PASS = num_pass
     # ============ end configure ======================
     for pp in list_keywods_path:
         jieba.load_userdict(pp)
@@ -92,7 +92,7 @@ def save_topic_weights(field,topics,weights_path):
     f_out_v.close()
     f_out_k.close()
 
-def lda_by_tag_each(list_category,root_path,weights_path,list_keywords_path,stopwords_path,minimum_num_doc=20,num_topics=6):
+def lda_by_tag_each(list_category,root_path,weights_path,list_keywords_path,stopwords_path,minimum_num_doc=20,num_topics=6,num_pass=5,num_words=50):
     if not os.path.exists(weights_path):
         os.mkdir(weights_path)
     print("Building topic models...")
@@ -109,5 +109,5 @@ def lda_by_tag_each(list_category,root_path,weights_path,list_keywords_path,stop
             list_doc.append(text)
         if len(list_doc) >= minimum_num_doc:
             print(country,len(list_doc))
-            LDA(country, list_doc,weights_path,list_keywords_path,stopwords_path,num_topics)
+            LDA(country, list_doc,weights_path,list_keywords_path,stopwords_path,num_topics,num_words,num_pass)
         print()
