@@ -1,12 +1,14 @@
 from quickcsv.file import *
 import os
 
-def get_news_by_year(meta_csv_file,raw_text_folder,output_folder,group_by="tag",time_field="time",id_field="Id"):
+def get_news_by_year(meta_csv_file,raw_text_folder,output_folder,group_by="tag",time_field="time",id_field="Id",
+    prefix_filename=""
+                     ):
     list_item = qc_read(meta_csv_file)
     count = 0
     total_records=len(list_item)
     for idx,item in enumerate(list_item):
-        print(f"{idx}/{total_records}")
+        # print(f"{idx}/{total_records}")
         # country
         country=item[group_by]
         if country=="":
@@ -21,7 +23,7 @@ def get_news_by_year(meta_csv_file,raw_text_folder,output_folder,group_by="tag",
             continue
         # file id
         file_id = item[id_field]
-        text_path = f"{raw_text_folder}/{file_id}.txt"
+        text_path = f"{raw_text_folder}/{prefix_filename}{file_id}.txt"
         if not os.path.exists(text_path):
             continue
         text = open(text_path, 'r', encoding='utf-8').read()
