@@ -102,7 +102,9 @@ def save_topic_weights(topic_weight_folder, year,topics):
 def do_lda_per_year(start_year,end_year, yearly_data_folder = "results/news_by_year",
                     save_topic_weight_folder="results/topic_weights",list_keywords_path=None,
                     stopwords_path="hit_stopwords.txt",
-
+                    num_topics=6,
+                    num_words=50,
+                    num_pass=5
                     ):
     print("Building topic model per year...")
     for year in range(start_year, end_year+1):
@@ -121,6 +123,6 @@ def do_lda_per_year(start_year,end_year, yearly_data_folder = "results/news_by_y
                 text = open(text_path, "r", encoding='utf-8').read()
                 list_doc.append(text)
         print(f"{year}'s news count: ", len(list_doc))
-        LDA(year, list_doc,save_topic_weight_folder,list_keywords_path,stopwords_path)
+        LDA(year, list_doc,save_topic_weight_folder,list_keywords_path,stopwords_path,NUM_TOPICS=num_topics,NUM_WORDS=num_words,NUM_PASS=num_pass)
         print()
 
