@@ -31,7 +31,10 @@ def show_year_month_trends_with_fulltext(
         year = ""
         if '-' in publishtime:
             ps = publishtime.split("-")
-            year_month = ps[0] + "-" + ps[1]
+            month=ps[1]
+            if len(month)==1:
+                month="0"+month
+            year_month = ps[0] + "-" + month
             year = int(ps[0])
         if year_month == "":
             continue
